@@ -11,10 +11,10 @@ from .mappers import Mapper
 from ..utils.filter_dict import clean_dict_of_keys
 from ..utils.is_integer import is_integer
 from ..utils.is_uuid import is_uuid
-from ..domain.entities import Entity1Entity
+from ..domain.entity1_entity import Entity1Entity
 
 # importa las excepciones personalizadas
-from ..domain.exceptions import (
+from ..domain.entity1_exceptions import (
     Entity1ValueError,
     Entity1ValidationError,
     Entity1AlreadyExistsError,
@@ -41,11 +41,9 @@ class Entity1Repository:
     """
 
     # Campos de la entidad no persistibles en el repositorio (para lógica de actualización)
-    # Los campos no persistibles son aquellos que nunca cambian como: id, uuid, created_at, updated_at, etc.
-    # aquellos que tienen una forma especial de ser guardados como: photo, password, etc.
-    # y también los campos ManyToManyField
+    # Los campos no persistibles son aquellos que tienen una forma especial de ser guardados como: photo, password, etc.
     ENTITY_NOT_PERSISTIBLE_FIELDS = {
-        'id', 'uuid', 'externals'
+        'photo', 'password'
     }    
 
     @staticmethod
@@ -144,7 +142,7 @@ class Entity1Repository:
             RepositoryError: Si ocurre un error inesperado (interno del sistema).
         """
         
-        # Lista de campos en los que se permite verificar unicidad
+        # Lista de campos en los que se permite verificar existencia
         ALLOWED_FIELDS = ['id', 'uuid', 'nombre', 'email', 'ruc', 'codigo']  # define según tu entidad
         
         if field_name not in ALLOWED_FIELDS:
@@ -217,14 +215,9 @@ class Entity1Repository:
             raise Entity1ValueError(field="Entity1", detail="Entity null or without methond 'to_dict'")
 
         try:
-            #convertir a dict
-            data = entity.to_dict()        
-
-            # Filtrar solo los campos actualizables
-            data = clean_dict_of_keys(data, keys=Entity1Repository.ENTITY_NOT_PERSISTIBLE_FIELDS)              
-
-            # Crear el registro a partir de los campos presentes en la 'data'
-            instance = Entity1(**data)
+            # Crear el registro a partir de los campos presentes en la 'entity'
+            instance = Entity1()
+            Mapper.update_model_from_entity(instance, entity, excluded_fields=Entity1Repository.ENTITY_NOT_PERSISTIBLE_FIELDS) 
 
             with transaction.atomic():
                 # Asegurar que todas las operaciones se realicen en una transacción
@@ -314,9 +307,7 @@ class Entity1Repository:
                 # Esto garantiza que si algo falla, no se guarden cambios parciales     
                 
                 # Actualizar cada campo de la entidad en el modelo
-                for key, value in entity.to_dict().items():
-                    if (key is not None) and (not key in Entity1Repository.ENTITY_NOT_PERSISTIBLE_FIELDS) and hasattr(instance, key):
-                        setattr(instance, key, value)                
+                Mapper.update_model_from_entity(instance, entity, excluded_fields=Entity1Repository.ENTITY_NOT_PERSISTIBLE_FIELDS)              
 
                 # Si se proporciona un ID de otra entidad, actualizarlo
                 if external_id is not None:
