@@ -6,16 +6,16 @@ from drf_yasg import openapi
 from rest_framework.permissions import IsAuthenticated
 
 # importar serializers
-from .serializers import [[ entity_name.capitalize() ]]DTOSerializer
+from .serializers import [[ entity_name|capitalize_first ]]DTOSerializer
 
 # importa las excepciones personalizadas
-from .domain.exceptions import (
-    [[ entity_name.capitalize() ]]ValueError,
-    [[ entity_name.capitalize() ]]ValidationError,
-    [[ entity_name.capitalize() ]]AlreadyExistsError,
-    [[ entity_name.capitalize() ]]NotFoundError,
-    [[ entity_name.capitalize() ]]OperationNotAllowedError,
-    [[ entity_name.capitalize() ]]PermissionError
+from .domain.[[ entity_name.lower() ]]_exceptions import (
+    [[ entity_name|capitalize_first ]]ValueError,
+    [[ entity_name|capitalize_first ]]ValidationError,
+    [[ entity_name|capitalize_first ]]AlreadyExistsError,
+    [[ entity_name|capitalize_first ]]NotFoundError,
+    [[ entity_name|capitalize_first ]]OperationNotAllowedError,
+    [[ entity_name|capitalize_first ]]PermissionError
 )
 
 # importa las excepciones de repositorio
@@ -25,12 +25,11 @@ from .infrastructure.exceptions import (
 )
 
 # Importar servicios específicos del dominio
-from [[ app_name.lower() ]].services.[[ entity_name.lower() ]]_service import [[ entity_name.capitalize() ]]Service
+from [[ app_name.lower() ]].services.[[ entity_name.lower() ]]_service import [[ entity_name|capitalize_first ]]Service
 
-class [[ entity_name.capitalize() ]]APIView(APIView):
+class [[ entity_name|capitalize_first ]]APIView(APIView):
     """
-    API para manejar operaciones CRUD relacionadas con [[ entity_name.lower() ]].
-
+    API para manejar operaciones CRUD relacionadas con [[ entity_name|decapitalize_first ]].
     Este APIView interactúa con:
     - Servicios del dominio que encapsulan la lógica de negocio.
     - Repositorios que interactúan con la capa de persistencia.
@@ -45,14 +44,14 @@ class [[ entity_name.capitalize() ]]APIView(APIView):
 
 
     @swagger_auto_schema(
-        operation_summary="Retrieve a list or a specific [[ entity_name.lower() ]]",
-        operation_description="Retrieve a list of all [[ entity_name.lower() ]] or a specific one by ID",
+        operation_summary="Retrieve a list or a specific [[ entity_name|decapitalize_first ]]",
+        operation_description="Retrieve a list of all [[ entity_name|decapitalize_first ]] or a specific one by ID",
         responses={
-            200: [[ entity_name.capitalize() ]]DTOSerializer,
+            200: [[ entity_name|capitalize_first ]]DTOSerializer,
             404: "Not Found",
             400: "Bad Request"
         },
-        tags=["[[ entity_name.lower() ]]"]
+        tags=["[[ entity_name|decapitalize_first ]]"]
     )
     def get(self, request, id=None):
         """
@@ -62,25 +61,25 @@ class [[ entity_name.capitalize() ]]APIView(APIView):
         - Si no se proporciona `id`, recupera todos los registros.
         """
 
-        [[ entity_name.lower() ]]Service = [[ entity_name.capitalize() ]]Service() # Instanciar el servicio
+        [[ entity_name|decapitalize_first ]]Service = [[ entity_name|capitalize_first ]]Service() # Instanciar el servicio
 
         if id is not None:
             # Recuperar un registro específico por ID
             try:
 
-                [[ entity_name.lower() ]] = [[ entity_name.lower() ]]Service.retrieve(entity_id=id)
+                [[ entity_name|decapitalize_first ]] = [[ entity_name|decapitalize_first ]]Service.retrieve(entity_id=id)
 
                 # Serializar el registro recuperado
-                response_serializer = [[ entity_name.capitalize() ]]DTOSerializer([[ entity_name.lower() ]])
+                response_serializer = [[ entity_name|capitalize_first ]]DTOSerializer([[ entity_name|decapitalize_first ]])
                 response_serializer.is_valid(raise_exception=True)
 
                 # Retornar la respuesta con un estado HTTP 200 OK
                 return Response(response_serializer.data, status=status.HTTP_200_OK)                     
 
-            except [[ entity_name.capitalize() ]]NotFoundError as e:
+            except [[ entity_name|capitalize_first ]]NotFoundError as e:
                 # Manejar errores si no se encuentra el registro
                 return Response({"error": str(e)}, status=status.HTTP_404_NOT_FOUND)
-            except [[ entity_name.capitalize() ]]ValueError as e:
+            except [[ entity_name|capitalize_first ]]ValueError as e:
                 # Manejar errores de validación si el ID no es válido
                 return Response({"error": str(e)}, status=status.HTTP_400_BAD_REQUEST)
             except (ConnectionDataBaseError, RepositoryError) as e:
@@ -93,16 +92,16 @@ class [[ entity_name.capitalize() ]]APIView(APIView):
         else:
             # Recuperar todos los registros
             try:
-                [[ entity_name.lower() ]]List = [[ entity_name.lower() ]]Service.list()
+                [[ entity_name|decapitalize_first ]]List = [[ entity_name|decapitalize_first ]]Service.list()
 
                 # Serializar la lista de registros
-                response_serializer_list = [[ entity_name.capitalize() ]]DTOSerializer([[ entity_name.lower() ]]List, many=True)
+                response_serializer_list = [[ entity_name|capitalize_first ]]DTOSerializer([[ entity_name|decapitalize_first ]]List, many=True)
                 response_serializer_list.is_valid(raise_exception=True)
 
                 # Retornar la respuesta con un estado HTTP 200 OK
                 return Response(response_serializer_list.data, status=status.HTTP_200_OK)                          
 
-            except ([[ entity_name.capitalize() ]]ValueError) as e:
+            except ([[ entity_name|capitalize_first ]]ValueError) as e:
                 # Manejar errores de validación si los datos no son válidos
                 return Response({"error": str(e)}, status=status.HTTP_400_BAD_REQUEST)
             except (ConnectionDataBaseError, RepositoryError) as e:
@@ -114,14 +113,14 @@ class [[ entity_name.capitalize() ]]APIView(APIView):
 
 
     @swagger_auto_schema(
-        operation_summary="Create a new [[ entity_name.lower() ]]",
-        operation_description="Create a new [[ entity_name.lower() ]] with the provided data",
-        request_body=[[ entity_name.capitalize() ]]DTOSerializer,
+        operation_summary="Create a new [[ entity_name|decapitalize_first ]]",
+        operation_description="Create a new [[ entity_name|decapitalize_first ]] with the provided data",
+        request_body=[[ entity_name|capitalize_first ]]DTOSerializer,
         responses={
-            201: [[ entity_name.capitalize() ]]DTOSerializer,
+            201: [[ entity_name|capitalize_first ]]DTOSerializer,
             400: "Bad Request"
         },
-        tags=["[[ entity_name.lower() ]]"]
+        tags=["[[ entity_name|decapitalize_first ]]"]
     )
     def post(self, request):
         """
@@ -132,7 +131,7 @@ class [[ entity_name.capitalize() ]]APIView(APIView):
         """
         
         # Datos enviados en el cuerpo de la solicitud
-        serializer = [[ entity_name.capitalize() ]]DTOSerializer(data=request.data) 
+        serializer = [[ entity_name|capitalize_first ]]DTOSerializer(data=request.data) 
         if not serializer.is_valid():
             # Si la validación falla, retornar un error 400 BAD REQUEST
             return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)
@@ -143,23 +142,22 @@ class [[ entity_name.capitalize() ]]APIView(APIView):
         # Si se proporcionan IDs de entidades relacionadas, agregarlos
         externals = request.data.get('externals', None)
 
-        [[ entity_name.lower() ]]Service = [[ entity_name.capitalize() ]]Service() # Instanciar el servicio        
+        [[ entity_name|decapitalize_first ]]Service = [[ entity_name|capitalize_first ]]Service() # Instanciar el servicio        
 
         try:
             # Llamar al servicio de creación con los datos proporcionados
-            [[ entity_name.lower() ]] = [[ entity_name.lower() ]]Service.create(data=serializer.validated_data, external_id=external_id, externals=externals)
-
+            [[ entity_name|decapitalize_first ]] = [[ entity_name|decapitalize_first ]]Service.create(data=serializer.validated_data, external_id=external_id, externals=externals)
             # Serializar el nuevo registro creado
-            response_serializer = [[ entity_name.capitalize() ]]DTOSerializer([[ entity_name.lower() ]])
+            response_serializer = [[ entity_name|capitalize_first ]]DTOSerializer([[ entity_name|decapitalize_first ]])
             response_serializer.is_valid(raise_exception=True)
 
             # Retornar la respuesta con un estado HTTP 201 CREATED
             return Response(response_serializer.data, status=status.HTTP_201_CREATED)
 
-        except [[ entity_name.capitalize() ]]AlreadyExistsError as e:
+        except [[ entity_name|capitalize_first ]]AlreadyExistsError as e:
             # Manejar errores si ya existe un registro con el mismo nombre
             return Response({"error": str(e)}, status=status.HTTP_400_BAD_REQUEST)
-        except ([[ entity_name.capitalize() ]]ValueError, [[ entity_name.capitalize() ]]ValidationError) as e:
+        except ([[ entity_name|capitalize_first ]]ValueError, [[ entity_name|capitalize_first ]]ValidationError) as e:
             # Manejar errores de validación si los datos no son válidos
             return Response({"error": str(e)}, status=status.HTTP_400_BAD_REQUEST)
         except (ConnectionDataBaseError, RepositoryError) as e:
@@ -171,15 +169,15 @@ class [[ entity_name.capitalize() ]]APIView(APIView):
 
 
     @swagger_auto_schema(
-        operation_summary="Update an existing [[ entity_name.lower() ]]",
-        operation_description="Update an existing [[ entity_name.lower() ]] with the provided ID and data",
-        request_body=[[ entity_name.capitalize() ]]DTOSerializer,
+        operation_summary="Update an existing [[ entity_name|decapitalize_first ]]",
+        operation_description="Update an existing [[ entity_name|decapitalize_first ]] with the provided ID and data",
+        request_body=[[ entity_name|capitalize_first ]]DTOSerializer,
         responses={
-            200: [[ entity_name.capitalize() ]]DTOSerializer,
+            200: [[ entity_name|capitalize_first ]]DTOSerializer,
             400: "Bad Request",
             404: "Not Found"
         },
-        tags=["[[ entity_name.lower() ]]"]
+        tags=["[[ entity_name|decapitalize_first ]]"]
     )
     def put(self, request, id):
         """
@@ -190,7 +188,7 @@ class [[ entity_name.capitalize() ]]APIView(APIView):
         """
 
         # Datos enviados en el cuerpo de la solicitud
-        serializer = [[ entity_name.capitalize() ]]DTOSerializer(data=request.data) 
+        serializer = [[ entity_name|capitalize_first ]]DTOSerializer(data=request.data) 
         if not serializer.is_valid():
             # Si la validación falla, retornar un error 400 BAD REQUEST
             return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)
@@ -201,23 +199,23 @@ class [[ entity_name.capitalize() ]]APIView(APIView):
         # Si se proporcionan IDs de entidades relacionadas, agregarlos
         externals = request.data.get('externals', None)       
         
-        [[ entity_name.lower() ]]Service = [[ entity_name.capitalize() ]]Service() # Instanciar el servicio        
+        [[ entity_name|decapitalize_first ]]Service = [[ entity_name|capitalize_first ]]Service() # Instanciar el servicio        
 
         try:
             # Llamar al servicio de actualización con el ID y los nuevos datos
-            [[ entity_name.lower() ]] = [[ entity_name.lower() ]]Service.update(entity_id=id, data=serializer.validated_data, external_id=external_id, externals=externals)
+            [[ entity_name|decapitalize_first ]] = [[ entity_name|decapitalize_first ]]Service.update(entity_id=id, data=serializer.validated_data, external_id=external_id, externals=externals)
 
             # Serializar el registro actualizado
-            response_serializer = [[ entity_name.capitalize() ]]DTOSerializer([[ entity_name.lower() ]])
+            response_serializer = [[ entity_name|capitalize_first ]]DTOSerializer([[ entity_name|decapitalize_first ]])
             response_serializer.is_valid(raise_exception=True)
 
             # Retornar la respuesta con un estado HTTP 200 OK
             return Response(response_serializer.data, status=status.HTTP_200_OK)
 
-        except [[ entity_name.capitalize() ]]NotFoundError as e:
+        except [[ entity_name|capitalize_first ]]NotFoundError as e:
             # Manejar errores si no se encuentra el registro con el ID dado
             return Response({"error": str(e)}, status=status.HTTP_404_NOT_FOUND)
-        except ([[ entity_name.capitalize() ]]ValueError, [[ entity_name.capitalize() ]]ValidationError) as e:
+        except ([[ entity_name|capitalize_first ]]ValueError, [[ entity_name|capitalize_first ]]ValidationError) as e:
             # Manejar errores de validación si los datos no son válidos
             return Response({"error": str(e)}, status=status.HTTP_400_BAD_REQUEST)
         except (ConnectionDataBaseError, RepositoryError) as e:
@@ -229,14 +227,14 @@ class [[ entity_name.capitalize() ]]APIView(APIView):
 
 
     @swagger_auto_schema(
-        operation_summary="Delete an existing [[ entity_name.lower() ]]",
-        operation_description="Delete an existing [[ entity_name.lower() ]] with the provided ID",
+        operation_summary="Delete an existing [[ entity_name|decapitalize_first ]]",
+        operation_description="Delete an existing [[ entity_name|decapitalize_first ]] with the provided ID",
         responses={
             204: "No Content",
             400: "Bad Request",
             404: "Not Found"
         },
-        tags=["[[ entity_name.lower() ]]"]
+        tags=["[[ entity_name|decapitalize_first ]]"]
     )
     def delete(self, request, id):
         """
@@ -246,19 +244,19 @@ class [[ entity_name.capitalize() ]]APIView(APIView):
         - Llama al servicio de eliminación para manejar la lógica de negocio.
         """
         
-        [[ entity_name.lower() ]]Service = [[ entity_name.capitalize() ]]Service() # Instanciar el servicio
+        [[ entity_name|decapitalize_first ]]Service = [[ entity_name|capitalize_first ]]Service() # Instanciar el servicio
         
         try:
             # Llamar al servicio de eliminación con el ID proporcionado
-            [[ entity_name.lower() ]] = [[ entity_name.lower() ]]Service.delete(entity_id=id)
+            [[ entity_name|decapitalize_first ]] = [[ entity_name|decapitalize_first ]]Service.delete(entity_id=id)
 
             # Retornar una respuesta sin contenido con estado HTTP 204 NO CONTENT
             return Response(status=status.HTTP_204_NO_CONTENT)
 
-        except [[ entity_name.capitalize() ]]NotFoundError as e:
+        except [[ entity_name|capitalize_first ]]NotFoundError as e:
             # Manejar errores si no se encuentra el registro con el ID dado
             return Response({"error": str(e)}, status=status.HTTP_404_NOT_FOUND)
-        except ([[ entity_name.capitalize() ]]ValueError, [[ entity_name.capitalize() ]]ValidationError) as e:
+        except ([[ entity_name|capitalize_first ]]ValueError, [[ entity_name|capitalize_first ]]ValidationError) as e:
             # Manejar errores de validación si el ID no es válido
             return Response({"error": str(e)}, status=status.HTTP_400_BAD_REQUEST)
         except (ConnectionDataBaseError, RepositoryError) as e:
