@@ -1,5 +1,5 @@
 from dataclasses import dataclass, field
 from typing import Dict, List, Optional
 from uuid import UUID, uuid4
-from .exceptions import *
-from .schemas import *
\ No newline at end of file
+from .[[ entity_name.lower() ]]_exceptions import *
+from .[[ entity_name.lower() ]]_schemas import *
\ No newline at end of file
