@@ -5,21 +5,21 @@ from django.db.models import Q
 from django.forms import ValidationError
 
 # importa las entidades utilizadas aqui
-from ..models import [[ entity_name.capitalize() ]]
+from ..models import [[ entity_name|capitalize_first ]]
 from .mappers import Mapper
 from ..utils.filter_dict import clean_dict_of_keys
 from ..utils.is_integer import is_integer
 from ..utils.is_uuid import is_uuid
-from ..domain.entities import [[ entity_name.capitalize() ]]Entity
+from ..domain.[[ entity_name.lower() ]]_entity import [[ entity_name|capitalize_first ]]Entity
 
 # importa las excepciones personalizadas
-from ..domain.exceptions import (
-    [[ entity_name.capitalize() ]]ValueError,
-    [[ entity_name.capitalize() ]]ValidationError,
-    [[ entity_name.capitalize() ]]AlreadyExistsError,
-    [[ entity_name.capitalize() ]]NotFoundError,
-    [[ entity_name.capitalize() ]]OperationNotAllowedError,
-    [[ entity_name.capitalize() ]]PermissionError
+from ..domain.[[ entity_name.lower() ]]_exceptions import (
+    [[ entity_name|capitalize_first ]]ValueError,
+    [[ entity_name|capitalize_first ]]ValidationError,
+    [[ entity_name|capitalize_first ]]AlreadyExistsError,
+    [[ entity_name|capitalize_first ]]NotFoundError,
+    [[ entity_name|capitalize_first ]]OperationNotAllowedError,
+    [[ entity_name|capitalize_first ]]PermissionError
 )
 
 # importa las excepciones de repositorio
@@ -29,9 +29,9 @@ from .exceptions import (
 )
 
 
-class [[ entity_name.capitalize() ]]Repository:
+class [[ entity_name|capitalize_first ]]Repository:
     """
-    Repositorio para manejar la persistencia de datos de la entidad: [[ entity_name.lower() ]].
+    Repositorio para manejar la persistencia de datos de la entidad: [[ entity_name|decapitalize_first ]].
     
     Este repositorio incluye:
     - Validación de existencia de registros.
@@ -40,35 +40,33 @@ class [[ entity_name.capitalize() ]]Repository:
     """
 
     # Campos de la entidad no persistibles en el repositorio (para lógica de actualización)
-    # Los campos no persistibles son aquellos que nunca cambian como: id, uuid, created_at, updated_at, etc.
-    # aquellos que tienen una forma especial de ser guardados como: photo, password, etc.
-    # y también los campos ManyToManyField
+    # Los campos no persistibles son aquellos que tienen una forma especial de ser guardados como: photo, password, etc.
     ENTITY_NOT_PERSISTIBLE_FIELDS = {
-        'id', 'uuid', 'externals'
+        'photo', 'password'
     }    
 
     @staticmethod
-    def get_all(filters: Optional[dict] = None) -> List[ [[ entity_name.capitalize() ]]Entity ]:
+    def get_all(filters: Optional[dict] = None) -> List[ [[ entity_name|capitalize_first ]]Entity ]:
         """
         Obtiene todos los registros de la entidad.
 
         params:
             filters (dict, optional): Filtros a aplicar en la consulta.
         returns: 
-            List[ [[ entity_name.capitalize() ]]Entity ]: Lista de entidades recuperadas.
+            List[ [[ entity_name|capitalize_first ]]Entity ]: Lista de entidades recuperadas.
         raises:
-            [[ entity_name.capitalize() ]]ValueError:  Si el valor de entrada no es válido.
+            [[ entity_name|capitalize_first ]]ValueError:  Si el valor de entrada no es válido.
             ConnectionDataBaseError: Si hay un error al conectar a la base de datos.
             RepositoryError: Si ocurre un error inesperado (interno del sistema).
         """
 
         try:
-            instance_list = [[ entity_name.capitalize() ]].objects.all()    
+            instance_list = [[ entity_name|capitalize_first ]].objects.all()    
 
             # Aplicar filtros si se proporcionan
             if filters is not None:
                 if not isinstance(filters, dict):
-                    raise [[ entity_name.capitalize() ]]ValueError(field="filters", detail="filters must be a dict or None")
+                    raise [[ entity_name|capitalize_first ]]ValueError(field="filters", detail="filters must be a dict or None")
                 if "nombre" in filters and filters["nombre"].strip():
                     instance_list = instance_list.filter(nombre__icontains=filters["nombre"])      
                     
@@ -76,7 +74,7 @@ class [[ entity_name.capitalize() ]]Repository:
             instance_list = instance_list.only("id", "nombre", "created_at")
 
             # Convertir a entidades usando el Mapper genérico
-            return [Mapper.model_to_entity(instance, [[ entity_name.capitalize() ]]Entity) for instance in instance_list]        
+            return [Mapper.model_to_entity(instance, [[ entity_name|capitalize_first ]]Entity) for instance in instance_list]        
 
         except DatabaseError as e:
             raise ConnectionDataBaseError("Data base access error") from e
@@ -85,7 +83,7 @@ class [[ entity_name.capitalize() ]]Repository:
 
 
     @staticmethod
-    def get_by_id(id = None, uuid = None) -> Optional[ [[ entity_name.capitalize() ]]Entity ]:
+    def get_by_id(id = None, uuid = None) -> Optional[ [[ entity_name|capitalize_first ]]Entity ]:
         """
         Obtiene un registro por su ID o UUID.
         
@@ -95,8 +93,8 @@ class [[ entity_name.capitalize() ]]Repository:
         returns: 
             El entidad encontrada o None si no existe.
         raises:
-            [[ entity_name.capitalize() ]]ValueError: Si el valor de entrada no es válido.        
-            [[ entity_name.capitalize() ]]NotFoundError: Si no existe el registro con el ID dado.
+            [[ entity_name|capitalize_first ]]ValueError: Si el valor de entrada no es válido.        
+            [[ entity_name|capitalize_first ]]NotFoundError: Si no existe el registro con el ID dado.
             ConnectionDataBaseError: Si ocurre un error al acceder a la base de datos.
             RepositoryError: Si ocurre un error inesperado (interno del sistema).
         """
@@ -104,23 +102,23 @@ class [[ entity_name.capitalize() ]]Repository:
         # Validar que el ID sea un entero o el UUID sea un UUID válido
         if id is not None: 
             if not is_integer(id):
-                raise [[ entity_name.capitalize() ]]ValueError(field="id", detail="ID must be integer.")
+                raise [[ entity_name|capitalize_first ]]ValueError(field="id", detail="ID must be integer.")
         elif uuid is not None:
             if not is_uuid(uuid):
-                raise [[ entity_name.capitalize() ]]ValueError(field="uuid", detail="UUID must be valid.")
+                raise [[ entity_name|capitalize_first ]]ValueError(field="uuid", detail="UUID must be valid.")
         else:
-            raise [[ entity_name.capitalize() ]]ValueError(field="id/uuid", detail="Either id or uuid must be provided.")
+            raise [[ entity_name|capitalize_first ]]ValueError(field="id/uuid", detail="Either id or uuid must be provided.")
 
         try:
             if id is not None:
-                instance = [[ entity_name.capitalize() ]].objects.get(id=id)
+                instance = [[ entity_name|capitalize_first ]].objects.get(id=id)
             else:
-                instance = [[ entity_name.capitalize() ]].objects.get(uuid=uuid)
+                instance = [[ entity_name|capitalize_first ]].objects.get(uuid=uuid)
 
-            return Mapper.model_to_entity(instance, [[ entity_name.capitalize() ]]Entity)
+            return Mapper.model_to_entity(instance, [[ entity_name|capitalize_first ]]Entity)
 
-        except [[ entity_name.capitalize() ]].DoesNotExist as e:
-            raise [[ entity_name.capitalize() ]]NotFoundError(id=id) from e
+        except [[ entity_name|capitalize_first ]].DoesNotExist as e:
+            raise [[ entity_name|capitalize_first ]]NotFoundError(id=id) from e
         except DatabaseError as e:
             raise ConnectionDataBaseError("Data base access error") from e    
         except Exception as e:
@@ -138,19 +136,19 @@ class [[ entity_name.capitalize() ]]Repository:
         returns:
             True si existe un registro con el valor dado, False en caso contrario.
         raises:
-            [[ entity_name.capitalize() ]]ValueError:  Si el valor de entrada no es válido.
+            [[ entity_name|capitalize_first ]]ValueError:  Si el valor de entrada no es válido.
             ConnectionDataBaseError: Si ocurre un error al acceder a la base de datos.
             RepositoryError: Si ocurre un error inesperado (interno del sistema).
         """
         
-        # Lista de campos en los que se permite verificar unicidad
+        # Lista de campos en los que se permite verificar existencia
         ALLOWED_FIELDS = ['id', 'uuid', 'nombre', 'email', 'ruc', 'codigo']  # define según tu entidad
         
         if field_name not in ALLOWED_FIELDS:
-            raise [[ entity_name.capitalize() ]]ValueError(field=field_name, detail=f"El campo '{field_name}' no es válido para verificar existencia.")
+            raise [[ entity_name|capitalize_first ]]ValueError(field=field_name, detail=f"El campo '{field_name}' no es válido para verificar existencia.")
 
         try:
-            return [[ entity_name.capitalize() ]].objects.filter(**{field_name: value}).exists()
+            return [[ entity_name|capitalize_first ]].objects.filter(**{field_name: value}).exists()
 
         except DatabaseError as e:
             raise ConnectionDataBaseError("Data base access error") from e
@@ -168,18 +166,18 @@ class [[ entity_name.capitalize() ]]Repository:
         returns:
             Número de registros que cumplen las condiciones.
         raises: 
-            [[ entity_name.capitalize() ]]ValueError:  Si el valor de entrada no es válido.
+            [[ entity_name|capitalize_first ]]ValueError:  Si el valor de entrada no es válido.
             ConnectionDataBaseError: Si ocurre un error al acceder a la base de datos.       
             RepositoryError: Si ocurre un error inesperado (interno del sistema). 
         """     
 
         try:
-            instance_list = [[ entity_name.capitalize() ]].objects.all()    
+            instance_list = [[ entity_name|capitalize_first ]].objects.all()    
 
             # Aplicar filtros si se proporcionan
             if filters is not None:
                 if not isinstance(filters, dict):
-                    raise [[ entity_name.capitalize() ]]ValueError(field="filters", detail="filters must be dict or None")               
+                    raise [[ entity_name|capitalize_first ]]ValueError(field="filters", detail="filters must be dict or None")               
                 if "nombre" in filters and filters["nombre"].strip():
                     instance_list = instance_list.filter(nombre__icontains=filters["nombre"])            
 
@@ -192,7 +190,7 @@ class [[ entity_name.capitalize() ]]Repository:
 
 
     @staticmethod
-    def create(entity: [[ entity_name.capitalize() ]]Entity, external_id: Optional[int], externals: Optional[List[int]], adicionalData=None) -> [[ entity_name.capitalize() ]]Entity:
+    def create(entity: [[ entity_name|capitalize_first ]]Entity, external_id: Optional[int], externals: Optional[List[int]], adicionalData=None) -> [[ entity_name|capitalize_first ]]Entity:
         """
         Crea un nuevo registro.
 
@@ -204,26 +202,21 @@ class [[ entity_name.capitalize() ]]Repository:
         returns: 
             La entidad creada.
         raises:
-            [[ entity_name.capitalize() ]]ValueError:  Si el valor de entrada no es válido.
-            [[ entity_name.capitalize() ]]ValidationError: Si los datos no son válidos.
-            [[ entity_name.capitalize() ]]AlreadyExistsError: Si ya existe un registro con el mismo nombre.
+            [[ entity_name|capitalize_first ]]ValueError:  Si el valor de entrada no es válido.
+            [[ entity_name|capitalize_first ]]ValidationError: Si los datos no son válidos.
+            [[ entity_name|capitalize_first ]]AlreadyExistsError: Si ya existe un registro con el mismo nombre.
             ConnectionDataBaseError: Si ocurre un error al acceder a la base de datos.   
             RepositoryError: Si ocurre un error inesperado (interno del sistema).     
         """
 
         # Validar la entidad de entrada
         if not entity or not hasattr(entity, "to_dict"):
-            raise [[ entity_name.capitalize() ]]ValueError(field="[[ entity_name.capitalize() ]]", detail="Entity null or without methond 'to_dict'")
+            raise [[ entity_name|capitalize_first ]]ValueError(field="[[ entity_name|capitalize_first ]]", detail="Entity null or without methond 'to_dict'")
 
         try:
-            #convertir a dict
-            data = entity.to_dict()        
-
-            # Filtrar solo los campos actualizables
-            data = clean_dict_of_keys(data, keys=[[ entity_name.capitalize() ]]Repository.ENTITY_NOT_PERSISTIBLE_FIELDS)              
-
-            # Crear el registro a partir de los campos presentes en la 'data'
-            instance = [[ entity_name.capitalize() ]](**data)
+            # Crear el registro a partir de los campos presentes en la 'entity'
+            instance = [[ entity_name|capitalize_first ]]()
+            Mapper.update_model_from_entity(instance, entity, excluded_fields=[[ entity_name|capitalize_first ]]Repository.ENTITY_NOT_PERSISTIBLE_FIELDS) 
 
             with transaction.atomic():
                 # Asegurar que todas las operaciones se realicen en una transacción
@@ -250,24 +243,24 @@ class [[ entity_name.capitalize() ]]Repository:
                     instance.externals.set(externals)                
 
         except (TypeError, ValueError) as e:
-            raise [[ entity_name.capitalize() ]]ValueError(field="data", detail=f"Error in the data structure: {str(e)}") from e
+            raise [[ entity_name|capitalize_first ]]ValueError(field="data", detail=f"Error in the data structure: {str(e)}") from e
         except ValidationError as e:
-            raise [[ entity_name.capitalize() ]]ValidationError(f"Validation error: {e.message_dict}") from e
+            raise [[ entity_name|capitalize_first ]]ValidationError(f"Validation error: {e.message_dict}") from e
         except IntegrityError as e:
             if 'duplicate' in str(e).lower() or 'unique constraint' in str(e).lower():
-                raise [[ entity_name.capitalize() ]]AlreadyExistsError(field='attributeName', detail=instance.attributeName)  # Ajusta según el campo único
+                raise [[ entity_name|capitalize_first ]]AlreadyExistsError(field='attributeName', detail=instance.attributeName)  # Ajusta según el campo único
             # Otro error de integridad → regla de negocio?
-            raise [[ entity_name.capitalize() ]]ValidationError({"integrity": "Duplicated or inconsistent data"})            
+            raise [[ entity_name|capitalize_first ]]ValidationError({"integrity": "Duplicated or inconsistent data"})            
         except DatabaseError as e:
             raise ConnectionDataBaseError("Data base access error") from e
         except Exception as e:
             raise RepositoryError(f"Error creating register: {str(e)}") from e
         
-        return Mapper.model_to_entity(instance, [[ entity_name.capitalize() ]]Entity)
+        return Mapper.model_to_entity(instance, [[ entity_name|capitalize_first ]]Entity)
 
 
     @staticmethod
-    def update(entity: [[ entity_name.capitalize() ]]Entity, external_id: Optional[int], externals: Optional[List[int]], adicionalData=None) -> [[ entity_name.capitalize() ]]Entity:
+    def update(entity: [[ entity_name|capitalize_first ]]Entity, external_id: Optional[int], externals: Optional[List[int]], adicionalData=None) -> [[ entity_name|capitalize_first ]]Entity:
         """
         Guarda los cambios en una entidad existente.
 
@@ -279,43 +272,41 @@ class [[ entity_name.capitalize() ]]Repository:
         returns:
             La entidad guardada.
         raises: 
-            [[ entity_name.capitalize() ]]NotFoundError: Si no existe el registro con el ID dado.
-            [[ entity_name.capitalize() ]]ValueError:  Si el valor de entrada no es válido.
-            [[ entity_name.capitalize() ]]ValidationError: Si los datos no son válidos.
+            [[ entity_name|capitalize_first ]]NotFoundError: Si no existe el registro con el ID dado.
+            [[ entity_name|capitalize_first ]]ValueError:  Si el valor de entrada no es válido.
+            [[ entity_name|capitalize_first ]]ValidationError: Si los datos no son válidos.
             ConnectionDataBaseError: Si ocurre un error al acceder a la base de datos.   
             RepositoryError: Si ocurre un error inesperado (interno del sistema).     
         """    
 
         # Validar la entidad de entrada
         if not entity or not hasattr(entity, "to_dict"):
-            raise [[ entity_name.capitalize() ]]ValueError(field="[[ entity_name.capitalize() ]]", detail="Entity null or without method 'to_dict'")
+            raise [[ entity_name|capitalize_first ]]ValueError(field="[[ entity_name|capitalize_first ]]", detail="Entity null or without method 'to_dict'")
 
         # Validar que tenga el id o uuid
         if not entity.id and not entity.uuid:
-            raise [[ entity_name.capitalize() ]]ValueError(field="id/uuid", detail="The id or uuid field is required")
+            raise [[ entity_name|capitalize_first ]]ValueError(field="id/uuid", detail="The id or uuid field is required")
 
         # validar el id
         if not entity.id or not is_integer(entity.id):
-            raise [[ entity_name.capitalize() ]]ValueError(field="id", detail="Id must be integer.")
+            raise [[ entity_name|capitalize_first ]]ValueError(field="id", detail="Id must be integer.")
 
         # validar el uuid
         if entity.uuid and not is_uuid(entity.uuid):
-            raise [[ entity_name.capitalize() ]]ValueError(field="uuid", detail="UUID must be valid.")
+            raise [[ entity_name|capitalize_first ]]ValueError(field="uuid", detail="UUID must be valid.")
 
         try:
             if entity.id:
-                instance = [[ entity_name.capitalize() ]].objects.get(id=entity.id)
+                instance = [[ entity_name|capitalize_first ]].objects.get(id=entity.id)
             else:
-                instance = [[ entity_name.capitalize() ]].objects.get(uuid=entity.uuid)
+                instance = [[ entity_name|capitalize_first ]].objects.get(uuid=entity.uuid)
 
             with transaction.atomic():
                 # Asegurar que todas las operaciones se realicen en una transacción
                 # Esto garantiza que si algo falla, no se guarden cambios parciales     
                 
                 # Actualizar cada campo de la entidad en el modelo
-                for key, value in entity.to_dict().items():
-                    if (key is not None) and (not key in [[ entity_name.capitalize() ]]Repository.ENTITY_NOT_PERSISTIBLE_FIELDS) and hasattr(instance, key):
-                        setattr(instance, key, value)                
+                Mapper.update_model_from_entity(instance, entity, excluded_fields=[[ entity_name|capitalize_first ]]Repository.ENTITY_NOT_PERSISTIBLE_FIELDS)              
 
                 # Si se proporciona un ID de otra entidad, actualizarlo
                 if external_id is not None:
@@ -336,14 +327,14 @@ class [[ entity_name.capitalize() ]]Repository:
                     instance.externals.set(externals)                
             
             # Convertir el modelo actualizado de vuelta a una entidad
-            return Mapper.model_to_entity(instance, [[ entity_name.capitalize() ]]Entity)
+            return Mapper.model_to_entity(instance, [[ entity_name|capitalize_first ]]Entity)
 
-        except [[ entity_name.capitalize() ]].DoesNotExist as e:
-            raise [[ entity_name.capitalize() ]]NotFoundError(id=entity.id) from e
+        except [[ entity_name|capitalize_first ]].DoesNotExist as e:
+            raise [[ entity_name|capitalize_first ]]NotFoundError(id=entity.id) from e
         except (TypeError, ValueError) as e:
-            raise [[ entity_name.capitalize() ]]ValueError(field="data", detail=f"Error inthe data structure: {str(e)}") from e
+            raise [[ entity_name|capitalize_first ]]ValueError(field="data", detail=f"Error inthe data structure: {str(e)}") from e
         except ValidationError as e:
-            raise [[ entity_name.capitalize() ]]ValidationError(f"Validation error: {e.message_dict}") from e
+            raise [[ entity_name|capitalize_first ]]ValidationError(f"Validation error: {e.message_dict}") from e
         except DatabaseError as e:
             raise ConnectionDataBaseError("Data base access error") from e            
         except Exception as e:
@@ -359,9 +350,9 @@ class [[ entity_name.capitalize() ]]Repository:
             id: ID del registro a eliminar.
             uuid: UUID del registro a eliminar.
         raises: 
-            [[ entity_name.capitalize() ]]NotFoundError: Si no existe el registro con el ID dado.
-            [[ entity_name.capitalize() ]]ValueError:  Si el valor de entrada no es válido.
-            [[ entity_name.capitalize() ]]ValidationError: Si los datos no son válidos
+            [[ entity_name|capitalize_first ]]NotFoundError: Si no existe el registro con el ID dado.
+            [[ entity_name|capitalize_first ]]ValueError:  Si el valor de entrada no es válido.
+            [[ entity_name|capitalize_first ]]ValidationError: Si los datos no son válidos
             ConnectionDataBaseError: Si ocurre un error al acceder a la base de datos.      
             RepositoryError: Si ocurre un error inesperado (interno del sistema).  
         returns: 
@@ -370,29 +361,29 @@ class [[ entity_name.capitalize() ]]Repository:
 
         # Validar que haya un id o uuid
         if id is None and uuid is None:
-            raise [[ entity_name.capitalize() ]]ValueError(field="id/uuid", detail="The id or uuid field is required")
+            raise [[ entity_name|capitalize_first ]]ValueError(field="id/uuid", detail="The id or uuid field is required")
 
         # validar el id
         if id is not None and not is_integer(id):
-            raise [[ entity_name.capitalize() ]]ValueError(field="id", detail="El ID debe ser un entero.")
+            raise [[ entity_name|capitalize_first ]]ValueError(field="id", detail="El ID debe ser un entero.")
 
         # validar el uuid
         if uuid is not None and not is_uuid(uuid):
-            raise [[ entity_name.capitalize() ]]ValueError(field="uuid", detail="El UUID debe ser válido.")
+            raise [[ entity_name|capitalize_first ]]ValueError(field="uuid", detail="El UUID debe ser válido.")
 
         try:
             if id is not None:
-                instance = [[ entity_name.capitalize() ]].objects.get(id=id)
+                instance = [[ entity_name|capitalize_first ]].objects.get(id=id)
             else:
-                instance = [[ entity_name.capitalize() ]].objects.get(uuid=uuid)
+                instance = [[ entity_name|capitalize_first ]].objects.get(uuid=uuid)
     
             instance.delete()
             return True
 
-        except [[ entity_name.capitalize() ]].DoesNotExist as e:
-            raise [[ entity_name.capitalize() ]]NotFoundError(id=id) from e
+        except [[ entity_name|capitalize_first ]].DoesNotExist as e:
+            raise [[ entity_name|capitalize_first ]]NotFoundError(id=id) from e
         except ValidationError as e:
-            raise [[ entity_name.capitalize() ]]ValidationError(f"Validation error occurred: {e.message_dict}") from e
+            raise [[ entity_name|capitalize_first ]]ValidationError(f"Validation error occurred: {e.message_dict}") from e
         except DatabaseError as e:
             raise ConnectionDataBaseError("Data base access error") from e            
         except Exception as e:
@@ -444,44 +435,44 @@ Por eso, es valioso **enriquecerlo estratégicamente**, manteniendo la coherenci
     En lugar de exponer solo filtros genéricos por `nombre`, puedes agregar métodos que expresen reglas de negocio:
         @staticmethod
         def get_activos():
-            return [[ entity_name.capitalize() ]].objects.filter(estado='activo')
+            return [[ entity_name|capitalize_first ]].objects.filter(estado='activo')
 
         @staticmethod
-        def find_by_slug(slug: str) -> Optional[[ entity_name.capitalize() ]]Entity:
+        def find_by_slug(slug: str) -> Optional[[ entity_name|capitalize_first ]]Entity:
             try:
-                instance = [[ entity_name.capitalize() ]].objects.get(slug=slug)
-                return Mapper.model_to_entity(instance, [[ entity_name.capitalize() ]]Entity)
-            except [[ entity_name.capitalize() ]].DoesNotExist:
+                instance = [[ entity_name|capitalize_first ]].objects.get(slug=slug)
+                return Mapper.model_to_entity(instance, [[ entity_name|capitalize_first ]]Entity)
+            except [[ entity_name|capitalize_first ]].DoesNotExist:
                 return None
 
     Estos métodos se integran naturalmente con `get_by_id()` y `get_all()`, y evitan que la lógica de negocio se repita en servicios.
 
 #### 2. 🔍 **QuerySets y Managers personalizados**
     Puedes encapsular lógica común (como filtros por estado o relaciones) en un `Manager` personalizado:
-        class [[ entity_name.capitalize() ]]Manager(models.Manager):
+        class [[ entity_name|capitalize_first ]]Manager(models.Manager):
             def activos(self):
                 return self.filter(estado='activo')
             def con_relacion(self):
                 return self.select_related('external').prefetch_related('externals')
 
-        class [[ entity_name.capitalize() ]](models.Model):
+        class [[ entity_name|capitalize_first ]](models.Model):
             ...
-            objects = [[ entity_name.capitalize() ]]Manager()
+            objects = [[ entity_name|capitalize_first ]]Manager()
 
     Luego, en el repositorio:
         @staticmethod
         def get_all(filters=None):
-            instance_list = [[ entity_name.capitalize() ]].objects.activos()  # Usa tu Manager
+            instance_list = [[ entity_name|capitalize_first ]].objects.activos()  # Usa tu Manager
             if filters and "nombre" in filters:
                 instance_list = instance_list.filter(nombre__icontains=filters["nombre"])
-            return [Mapper.model_to_entity(inst, [[ entity_name.capitalize() ]]Entity) for inst in instance_list]
+            return [Mapper.model_to_entity(inst, [[ entity_name|capitalize_first ]]Entity) for inst in instance_list]
 
         @staticmethod
         def get_all_with_relations():
-            instance_list = [[ entity_name.capitalize() ]].objects.activos().con_relacion() # Usa tu Manager
+            instance_list = [[ entity_name|capitalize_first ]].objects.activos().con_relacion() # Usa tu Manager
             if filters:
                 instance_list = instance_list.filter(nombre__icontains=filters["nombre"])
-            return [Mapper.model_to_entity(inst, [[ entity_name.capitalize() ]]Entity) for inst in instance_list]
+            return [Mapper.model_to_entity(inst, [[ entity_name|capitalize_first ]]Entity) for inst in instance_list]
 
     Así mantienes el diseño actual, pero con mejor rendimiento y expresividad.
 
@@ -492,24 +483,24 @@ Por eso, es valioso **enriquecerlo estratégicamente**, manteniendo la coherenci
         def get_paginated(page: int, size: int, filters=None):
             offset = (page - 1) * size
             limit = offset + size
-            instance_list = [[ entity_name.capitalize() ]].objects.all()
+            instance_list = [[ entity_name|capitalize_first ]].objects.all()
             if filters and "nombre" in filters:
                 instance_list = instance_list.filter(nombre__icontains=filters["nombre"])
             instance_list = instance_list.only("id", "nombre", "created_at")[offset:limit]
-            return [Mapper.model_to_entity(inst, [[ entity_name.capitalize() ]]Entity) for inst in instance_list]
+            return [Mapper.model_to_entity(inst, [[ entity_name|capitalize_first ]]Entity) for inst in instance_list]
 
     Ideal para APIs o listados grandes.
 
 #### 4. 🔄 **Separación de lectura y escritura (CQRS básico)**
     Aunque la plantilla combina lectura y escritura, puedes dividirla cuando el sistema escala:
 
-        class [[ entity_name.capitalize() ]]ReadRepository:
+        class [[ entity_name|capitalize_first ]]ReadRepository:
             @staticmethod
             def get_all(...):  # Igual al actual
             @staticmethod
             def count_all(...):  # Ya implementado
 
-        class [[ entity_name.capitalize() ]]WriteRepository:
+        class [[ entity_name|capitalize_first ]]WriteRepository:
             @staticmethod
             def create(...):   # Usa `adicionalData` para lógica especial
             @staticmethod
@@ -525,10 +516,10 @@ Por eso, es valioso **enriquecerlo estratégicamente**, manteniendo la coherenci
         from django.db.models import Count
         @staticmethod
         def get_con_muchos_externals(min_relaciones=3):
-            instances = [[ entity_name.capitalize() ]].objects.annotate(
+            instances = [[ entity_name|capitalize_first ]].objects.annotate(
                 total_externals=Count('externals')
             ).filter(total_externals__gt=min_relaciones)
-            return [Mapper.model_to_entity(inst, [[ entity_name.capitalize() ]]Entity) for inst in instances]
+            return [Mapper.model_to_entity(inst, [[ entity_name|capitalize_first ]]Entity) for inst in instances]
 
     Así mantienes el mapeo y la coherencia del dominio.
 
@@ -537,10 +528,10 @@ Por eso, es valioso **enriquecerlo estratégicamente**, manteniendo la coherenci
 
         @staticmethod
         def get_all_with_relations():
-            instance_list = [[ entity_name.capitalize() ]].objects.select_related('external').prefetch_related('externals')
+            instance_list = [[ entity_name|capitalize_first ]].objects.select_related('external').prefetch_related('externals')
             if filters:
                 instance_list = instance_list.filter(nombre__icontains=filters["nombre"])
-            return [Mapper.model_to_entity(inst, [[ entity_name.capitalize() ]]Entity) for inst in instance_list]
+            return [Mapper.model_to_entity(inst, [[ entity_name|capitalize_first ]]Entity) for inst in instance_list]
 
     Evita el problema N+1 cuando accedes a relaciones.
 
@@ -550,34 +541,34 @@ Por eso, es valioso **enriquecerlo estratégicamente**, manteniendo la coherenci
         from django.db.models import Q, 
         @staticmethod
         def search_advanced(query):
-            instances = [[ entity_name.capitalize() ]].objects.filter(
+            instances = [[ entity_name|capitalize_first ]].objects.filter(
                 Q(nombre__icontains=query) | Q(descripcion__icontains=query)
             )
-            return [Mapper.model_to_entity(inst, [[ entity_name.capitalize() ]]Entity) for inst in instances]
+            return [Mapper.model_to_entity(inst, [[ entity_name|capitalize_first ]]Entity) for inst in instances]
 
         @staticmethod
         def reactivar_registros():
-            [[ entity_name.capitalize() ]].objects.filter(estado='inactivo').update(estado=F('estado_anterior'))
+            [[ entity_name|capitalize_first ]].objects.filter(estado='inactivo').update(estado=F('estado_anterior'))
 
         @staticmethod
         def busqueda_compleja_sql():
             from django.db import connection
             with connection.cursor() as cursor:
-                cursor.execute("SELECT * FROM app_[[ entity_name.lower() ]] WHERE estado = %s", ['activo'])
+                cursor.execute("SELECT * FROM app_[[ entity_name|decapitalize_first ]] WHERE estado = %s", ['activo'])
                 rows = cursor.fetchall()
-            return [Mapper.model_to_entity(row, [[ entity_name.capitalize() ]]Entity) for row in rows]
+            return [Mapper.model_to_entity(row, [[ entity_name|capitalize_first ]]Entity) for row in rows]
 
     El repositorio sigue siendo el único punto de acceso al ORM.
 
 #### 8. **Documentación y claridad**
     Los métodos del repositorio deben reflejar intenciones del negocio, no solo operaciones técnicas:
         @staticmethod
-        def get_all(filters=None) -> List[[ entity_name.capitalize() ]]Entity:
+        def get_all(filters=None) -> List[[ entity_name|capitalize_first ]]Entity:
             """
-            Obtiene todos los [[ entity_name.lower() ]] que coincidan con los filtros.
+            Obtiene todos los [[ entity_name|decapitalize_first ]] que coincidan con los filtros.
             Usa `.only()` para optimizar rendimiento.
             :param filters: Diccionario con filtros (ej. {"nombre": "juan"}).
-            :return: Lista de entidades [[ entity_name.capitalize() ]].
+            :return: Lista de entidades [[ entity_name|capitalize_first ]].
             """
     Esto hace que el repositorio sea autoexplicativo.
 
@@ -592,8 +583,8 @@ Por eso, es valioso **enriquecerlo estratégicamente**, manteniendo la coherenci
                 pass
         
             def test_create_con_external_y_externals(self):
-                entity = [[ entity_name.capitalize() ]]Entity(nombre="Test")
-                created = [[ entity_name.capitalize() ]]Repository.create(
+                entity = [[ entity_name|capitalize_first ]]Entity(nombre="Test")
+                created = [[ entity_name|capitalize_first ]]Repository.create(
                     entity=entity,
                     external_id=1,
                     externals=[1, 2],
@@ -603,7 +594,7 @@ Por eso, es valioso **enriquecerlo estratégicamente**, manteniendo la coherenci
                 self.assertEqual(created.nombre, "Test")
 
                 # Verifica relaciones
-                instance = [[ entity_name.capitalize() ]].objects.get(id=created.id)
+                instance = [[ entity_name|capitalize_first ]].objects.get(id=created.id)
                 self.assertEqual(instance.external_id, 1)
                 self.assertEqual(instance.externals.count(), 2)
 
